OC.L10N.register(
    "firstrunwizard",
    {
    "Schedule work & meetings, synced with all your devices." : "Organizează munca & întâlnirile, sincronizat pe toate dispozitivele.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Un loc comun pentru colegi și prieteni fără scurgeri de informații private.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicație simplă de mail, integrată cu Fișiere, Contacte și Calendar.",
    "Access files via WebDAV" : "Accesează fișierele prin WebDAV",
    "Desktop client" : "Client desktop",
    "iOS app" : "Aplicație iOS",
    "Close" : "Închide",
    "Skip" : "Sari peste",
    "Privacy" : "Confidențialitate",
    "Community" : "Comunitate",
    "Get the apps to sync your files" : "Obține aplicația pentru sincronizarea fișierelor",
    "Server address" : "Adresă server",
    "What's new?" : "Ce este nou?",
    "Share on social media" : "Partajează pe rețelele de socializare",
    "Read more" : "Citește mai mult"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
